<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Sítios e vinculação em SPIP (privado e público)',
	'sites_slogan' => 'Gestão dos sítios e da vinculação em SPIP',
];
